Bifrost: src/UnitigIterator.hpp File Reference

Bifrost

Data Structures
UnitigIterator.hpp File Reference

The unitigIterator type interface. More...

Go to the source code of this file.

## Data Structures
class | CompactedDBG< Unitig_data_t, Graph_data_t >
| Represent a Compacted de Bruijn graph. More...
class | unitigIterator< Unitig_data_t, Graph_data_t, is_const >
| Iterator for the unitigs of a Compacted de Bruijn graph. More...

## Detailed Description

The unitigIterator type interface.

Code snippets using this interface are provided in snippets/test.cpp.